# -*- coding: utf-8 -*-

from django.shortcuts import render
from django.conf import settings


sample_div = getattr(settings, 'EXAMPLE_DIV', '')

def home(request):
    return render(request, 'home.html', {})


def game_slider(request):
    return render(request, 'game_slider.html', {})


def live_games(request):
    return render(request, 'live_games.html', {
        'divId': sample_div
    })


def standings(request):
    return render(request, 'standings.html', {
        'divId': sample_div
    })


def schedule(request):
    return render(request, 'schedule.html', {
        'divId': sample_div
    })


def knockout_stage(request):
    po_div = getattr(settings, 'EXAMPLE_PO_DIV', '')
    return render(request, 'knockout_stage.html', {
        'divId': po_div
    })


def game_report(request, gameId):
    return render(request, 'game_report.html', {
        'gameId': gameId, 
        'divId': sample_div
    })


def game_livebox(request, gameId, divId):
    return render(request, 'game_livebox.html', {
        'gameId': gameId,
        'divId': divId
    })


def game_playbyplay(request, gameId):
    return render(request, 'game_playbyplay.html', {
        'gameId': gameId,
        'divId': sample_div
    })


def player_stats(request):
    return render(request, 'player_stats.html', {
        'divId': sample_div
    })


def full_player(request, playerId):
    return render(request, 'full_player.html', {
        'playerId': playerId,
        'divId': sample_div
    })


def team_fullpage(request, teamId):
    return render(request, 'team_fullpage.html', {
        'teamId': teamId,
        'divId': sample_div
    })



"""mysite URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include
from django.conf import settings
from django.conf.urls.static import static
from . import views

urlpatterns = [
    path('admin/', admin.site.urls),
    path('', views.home, name='home'),
    path('game_slider/', views.game_slider, name='game_slider'),
    path('live_games/', views.live_games, name='live_games'),
    path('standings/', views.standings, name='standings'),
    path('schedule/', views.schedule, name='schedule'),
    path('knockout_stage/', views.knockout_stage, name='knockout_stage'),

    path('game_report/<str:gameId>/', views.game_report, name='game_report'),
    path('game_livebox/<str:gameId>/<str:divId>', views.game_livebox, name='game_livebox'),

    path('player_stats/', views.player_stats, name='player_stats'),
    path('full_player/<str:playerId>/', views.full_player, name='full_player'),
    path('team_fullpage/<str:teamId>/',
         views.team_fullpage, name='team_fullpage'),
]
urlpatterns += static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)



"""
Django settings for mysite project.

Generated by 'django-admin startproject' using Django 2.0.

For more information on this file, see
https://docs.djangoproject.com/en/2.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.0/ref/settings/
"""

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/2.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '0(b#+)rbras6t%^f7a-vkj0ktp3^4^@-mo3566ab4(#_qo__$w'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = []


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'hockeydata_api',
    'example',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'example.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'example.wsgi.application'


# Database
# https://docs.djangoproject.com/en/2.0/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}


# Password validation
# https://docs.djangoproject.com/en/2.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = []


# Internationalization
# https://docs.djangoproject.com/en/2.0/topics/i18n/

LANGUAGE_CODE = 'de-de'
TIME_ZONE = 'Europe/Berlin'
USE_I18N = True
USE_L10N = True
USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.0/howto/static-files/

STATIC_URL = '/static/'


# hockeydata_api settings
HOCKEYDATA = {
    # Hockeydata Api-Key (you can get it from https://apidocs.hockeydata.net/api-key/)
    'API_KEY': '',

    # Sport definition key: americanfootball|icehockey
    'SPORT': 'icehockey',

    # Base-URL to hockeydata static javascript and css 
    'STATIC': 'https://api.hockeydata.net/',

    # Default template: los_template_dark|los_template_glass|los_template_default
    'DEFAULT_CSS': 'los_template_dark',

    # localization i18n_x_los, where x is the ISO-639-1 language code (de = Germany)
    # https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
    'I18N': 'i18n_de_los',
}


# for demo purpose fill this with appropriate leage divisions of your organisation
EXAMPLE_DIV = '1903'
# playoff round
EXAMPLE_PO_DIV = '3011'



""" Silence pylint """

import json
from django.conf import settings
from django import template
from django.utils.safestring import mark_safe

register = template.Library()


def get_hd_attr(key, default=None):
    """ Get the hockeydata specific settings """
    hd_settings = getattr(settings, 'HOCKEYDATA', {})
    return hd_settings.get(key, default)


@register.inclusion_tag('hockeydata_api/include/hockeydata_widget.html')
def hockeydata_widget(dom_node, widget_name, division_id=None, **kwargs):
    """
    Render the hockeydata api widget code
    :param dom_node:
    :param widget_name:
    :param division_id:
    :param kwargs:
    :return:
    """
    options = kwargs
    options['domNode'] = dom_node
    options['widgetName'] = widget_name
    if division_id:
        options['divisionId'] = division_id
    else:
        options['error'] = 'DivisionId not provided.'

    api_key = get_hd_attr('API_KEY', '')
    sport = get_hd_attr('SPORT')
    if sport is None:
        options['error'] = 'HOCKEYDATA_SPORT not found in settings'
    else:
        options['apiKey'] = api_key
        options['sport'] = sport

    return {'options': json.dumps(options)}


@register.simple_tag
def hockeydata_css(*args):
    """
    Render the hockeydata api css references
    :param args:
    :return:
    """
    url = get_hd_attr('STATIC', '')
    if url is None:
        return mark_safe('Error: No HOCKEYDATA_STATIC in settings provided!')
    default_css = get_hd_attr('DEFAULT_CSS', '')

    if default_css is not None:
        css_links = '<link href="{url}css/?{default}" rel="stylesheet">\n'.format(
            url=url, default=default_css)
    else:
        css_links = '<link href="{url}css/?los_template_default" rel="stylesheet">\n'.format(
            url=url)

    widgets = '?{widget}'.format(widget=args[0])
    for widget in args[1:]:
        widgets += '&{widget}'.format(widget=widget)
    css_links += '<link href="{url}css/{widgets}" rel="stylesheet" >'.format(
        url=url, widgets=widgets)
    return mark_safe(css_links)


@register.simple_tag
def hockeydata_js(*args):
    """
    Render the hockeydata api javascript references
    :param args:
    :return:
    """
    sport = get_hd_attr('SPORT')
    if sport is None:
        return mark_safe('Error: No HOCKEYDATA_SPORT in settings provided!')
    i18n = get_hd_attr('I18N')
    i18n_opt = ''
    if i18n is not None:
        i18n_opt = '&{i18n}'.format(i18n=i18n)

    url = get_hd_attr('STATIC')
    if url is None:
        return mark_safe('Error: No HOCKEYDATA_STATIC in settings provided!')

    widgets = '?{widget}'.format(widget=args[0])
    for widget in args[1:]:
        widgets += '&{widget}'.format(widget=widget)

    js_template = '<script src="{url}js/{widgets}&los_configuration_{sport}{i18n}"></script>'
    js_assets = js_template.format(
        url=url, widgets=widgets,
        sport=sport, i18n=i18n_opt
    )
    return mark_safe(js_assets)



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='django_hockeydata_api',
    version='0.0.4',
    description='A Django package for simple use of Hockeydata Javascript API',
    url='https://git.wgdnet.de/cwiegand/django_hockeydata_api.git',
    author='Christian Wiegand',
    license='BSD',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=[
        'django',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Framework :: Django",
    ],
)
